@@ -19,7 +19,7 @@ import json
 
 # Code zappette
 code_Fb= "35782633"
-log.msg("*****************************")
+log.msg("*************  FREEBOX ****************")
 
 class Freebox(IPlugin):
 	def __init__(self):
